==> exit-options_24.10.01.tar.xz: BUILD/translations/exit-options_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="24"/>
        <source>Restart Fluxbox</source>
        <translation>Fluxbox neustarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Lock Screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Log Out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Pop-up mit Abmelde-Einstellungen für MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation>Buttons in vertikalem Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Buttons in horizontalem Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation>Timeout-Dauer in Sekunden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>Verwenden Sie -v, --vertical, um Schaltflächen vertikal anzuzeigen
Verwenden Sie -h, --horizontal, um die Schaltflächen horizontal anzuzeigen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Verwendung: Abmelde-Optionen [options]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation>Auswahlmöglichkeiten:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 Option zur horizontalen Anzeige von Schaltflächen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 Option zur vertikalen Anzeige von Schaltflächen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 Timeout-Dauer in Sekunden
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Die Auswahlmöglichkeiten zur Anzeigeausrichtung werden gespeichert und beim nächsten Start geladen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternativ können Sie die Option &apos;layout=horizontal&apos; oder &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf setzen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>Um das timeout in exit-options.conf einzustellen, verwenden Sie &apos;timeout=X&apos;, wobei X das timeout in Sekunden bedeutet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Sie können benutzerdefinierte Symbole definieren, indem Sie IconName=/path/iconame.ext in der Datei exit-options.conf hinzufügen. Die Namen der Symbole, die Sie neu zuordnen: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Weitere Optionen, die in der Datei exit-options.conf eingestellt werden können: %1</translation>
    </message>
</context>
</TS>

==> exit-options_25.1.tar.xz: BUILD/translations/exit-options_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation>Fluxbox neu starten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Restart IceWM</source>
        <translation>IceWM neu starten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Lock Screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="42"/>
        <source>Suspend</source>
        <translation>Bereitschaft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Pop-up mit Abmelde-Einstellungen für MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation>Buttons in vertikalem Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Buttons in horizontalem Fenster anzeigen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation>Timeout-Dauer in Sekunden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>Verwenden Sie -v, --vertical, um Schaltflächen vertikal anzuzeigen
Verwenden Sie -h, --horizontal, um die Schaltflächen horizontal anzuzeigen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Verwendung: Abmelde-Optionen [options]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation>Auswahlmöglichkeiten:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 Option zur horizontalen Anzeige von Schaltflächen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 Option zur vertikalen Anzeige von Schaltflächen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 Timeout-Dauer in Sekunden
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Die Auswahlmöglichkeiten zur Anzeigeausrichtung werden gespeichert und beim nächsten Start geladen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Alternativ können Sie die Option &apos;layout=horizontal&apos; oder &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf setzen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>Um das timeout in exit-options.conf einzustellen, verwenden Sie &apos;timeout=X&apos;, wobei X das timeout in Sekunden bedeutet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation>Sie können auch den Befehl &quot;timeout=off&quot; verwenden, um das Time-out zu deaktivieren.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Sie können benutzerdefinierte Symbole definieren, indem Sie IconName=/path/iconame.ext in der Datei exit-options.conf hinzufügen. Die Namen der Symbole, die Sie neu zuordnen: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Weitere Optionen, die in der Datei exit-options.conf eingestellt werden können: %1</translation>
    </message>
</context>
</TS>
